@@ -814,11 +814,10 @@ void RequestPrivate::followRedirect(const QUrl &redirect) {
 void RequestPrivate::refreshAccessToken() {
     Q_Q(Request);
     
-    QUrl tokenUrl(TOKEN_URL);
-    QNetworkRequest request(tokenUrl);
+    QNetworkRequest request(TOKEN_URL);
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
-    QString body("client_id=" + clientId + "&client_secret=" + clientSecret + "&refresh_token=" + refreshToken +
-                 "&grant_type=" + GRANT_TYPE_REFRESH);
+    const QString body("client_id=" + clientId + "&client_secret=" + clientSecret + "&refresh_token=" + refreshToken +
+                       "&grant_type=" + GRANT_TYPE_REFRESH);
                     
     if (reply) {
         delete reply;
@@ -861,7 +860,7 @@ void RequestPrivate::_q_onAccessTokenRefreshed() {
     }
         
     if (ok) {
-        QString token = result.toMap().value("access_token").toString();
+        const QString token = result.toMap().value("access_token").toString();
         
         if (token.isEmpty()) {
             setStatus(Request::Failed);
@@ -906,10 +905,10 @@ void RequestPrivate::_q_onReplyFinished() {
     Q_Q(Request);
     
     if (redirects < MAX_REDIRECTS) {
-        QUrl redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
+        QUrl redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
     
         if (redirect.isEmpty()) {
-            redirect = reply->header(QNetworkRequest::LocationHeader).toUrl();
+            redirect = reply->header(QNetworkRequest::LocationHeader).toString();
         }
     
         if (!redirect.isEmpty()) {
