@@ -14,8 +14,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef REQUEST_H
-#define REQUEST_H
+#ifndef QDAILYMOTION_REQUEST_H
+#define QDAILYMOTION_REQUEST_H
 
 #include "qdailymotion_global.h"
 #include <QObject>
@@ -155,13 +155,13 @@ protected Q_SLOTS:
 Q_SIGNALS:
     void clientIdChanged();
     void clientSecretChanged();
-    void accessTokenChanged();
-    void refreshTokenChanged();
+    void accessTokenChanged(const QString &token);
+    void refreshTokenChanged(const QString &token);
     void urlChanged();
     void dataChanged();
     void headersChanged();
     void operationChanged();
-    void statusChanged();
+    void statusChanged(Status s);
     void finished();
     
 protected:
@@ -180,4 +180,4 @@ private:
 
 }
 
-#endif // REQUEST_H
+#endif // QDAILYMOTION_REQUEST_H
